
Verbose version information
-------

**Description:**

Revealing system data or debugging information helps an adversary learn about the system 
and form a plan of attack. An information leak occurs when system data or debugging 
information leaves the program through an output stream or logging function.


**Solution:**

Verify that the HTTP headers do not expose detailed version information of system 
components

	